/* $Id: proto_gnuchess4.h,v 1.3 2002/06/14 17:32:57 bergo Exp $ */

/*

    eboard - chess client
    http://eboard.sourceforge.net
    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
    bergo@seul.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

// don't include this, include protocol.h instead

#ifndef EBOARD_GNUCHESS4
#define EBOARD_GNUCHESS4

class GnuChess4Protocol : public XBoardProtocol {
 public:
  GnuChess4Protocol();

  virtual void initEngine();
  virtual void readDialog();

 protected:
  virtual char *getDialogName();

};

#endif
